@@ -17,9 +17,8 @@ void dweibullder(double *x, int *nx, double *par, int *deriv, double *dder){
 				dder[i] = -par[0]/pow(x[i], 2)*pow(y[i], par[0])*exp(-pow(y[i], par[0]))*(par[0]*pow(y[i], par[0]) - par[0] + 1);
 			break;
 		case 3:
-			for (i = 0; i < *nx; i++){
+			for (i = 0; i < *nx; i++)
 				dder[i] = par[0]/pow(x[i], 3)*pow(y[i], par[0])*exp(-pow(y[i], par[0]))*(pow(par[0], 2)*pow(y[i], 2*par[0]) - 3*par[0] + 3*par[0]*pow(y[i], par[0]) - 3*pow(par[0], 2)*pow(y[i], par[0]) + pow(par[0], 2) + 2);
-			}
 			break;
 		case 4:
 			for (i = 0; i < *nx; i++)
